==> haskell-libxml-0.1.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-libxml.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libxml
version: 0.1.1
id: libxml-0.1.1-DASs7VNHhWqCsnCWtz5QqF
key: libxml-0.1.1-DASs7VNHhWqCsnCWtz5QqF
license: BSD3
copyright: 2006, Lemmih
maintainer: Lemmih (lemmih@gmail.com)
synopsis: Binding to libxml2
description:
    Minimal binding to libxml2. Additional functions will be added when needed.
category: XML
author: Lemmih (lemmih@gmail.com)
exposed: True
indefinite: False
exposed-modules:
    Text.XML.LibXML Text.XML.LibXML.Internals Text.XML.LibXML.Parser
    Text.XML.LibXML.Tree Text.XML.LibXML.Types
abi: 36f2ad8da3e6f422980792f0754dca28
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-0.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/libxml-0.1.1
hs-libraries: HSlibxml-0.1.1-DASs7VNHhWqCsnCWtz5QqF
extra-libraries:
    xml2
include-dirs: /usr/include/libxml2
includes:
    libxml/xmlIO.h libxml/xmlmemory.h
depends:
    base-4.10.1.0 bytestring-0.10.8.2 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
haddock-interfaces: /usr/share/doc/haskell-libxml/html/libxml.haddock
haddock-html: /usr/share/doc/haskell-libxml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libxml-0.1.1-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-libxml.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: libxml
version: 0.1.1
id: libxml-0.1.1-6avle8wIbEUHYYp5CH1n6O
key: libxml-0.1.1-6avle8wIbEUHYYp5CH1n6O
license: BSD3
copyright: 2006, Lemmih
maintainer: Lemmih (lemmih@gmail.com)
synopsis: Binding to libxml2
description:
    Minimal binding to libxml2. Additional functions will be added when needed.
category: XML
author: Lemmih (lemmih@gmail.com)
exposed: True
indefinite: False
exposed-modules:
    Text.XML.LibXML Text.XML.LibXML.Internals Text.XML.LibXML.Parser
    Text.XML.LibXML.Tree Text.XML.LibXML.Types
abi: bf957dc8a15245373045ced070bdd1fb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-0.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/libxml-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/libxml-0.1.1
hs-libraries: HSlibxml-0.1.1-6avle8wIbEUHYYp5CH1n6O
extra-libraries:
    xml2
include-dirs: /usr/include/libxml2
includes:
    libxml/xmlIO.h libxml/xmlmemory.h
depends:
    base-4.10.1.0 bytestring-0.10.8.2 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
haddock-interfaces: /usr/share/doc/haskell-libxml/html/libxml.haddock
haddock-html: /usr/share/doc/haskell-libxml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
